
# ====================================================================

	proc calcDirRatios {} {
		global dirs nDir dirSin dirCos

		set x    "N NNE NE ENE E ESE SE SSE S SSW SW WSW W WNW NW NNW"
		set dirs [split $x " "]
		set nDir [llength $dirs]

		set pi        [expr 2 * acos(0)]
		set angle 0
		set	angleIncr [expr $pi / 8]

		for {set i 0} {$i < $nDir} {incr i 1}  {
			set dir [lindex $dirs $i]

			set dirSin($dir)   [expr sin($angle)]
			set dirCos($dir)   [expr cos($angle)]

			set angle [expr $angle + $angleIncr]
		}
	}

# --------------------------------------------------------------------
	proc plotData {altMax color}  {
		global  nRow  time tDat wind station
		global  dirSin dirCos
		global  latestReading

		calcDirRatios

		for {set i 0} {$i < $nRow} {incr i 1}  {
			if [string match "*No Data*" $tDat($i)]  continue
			if { $tDat($i) == " " }  {
				set tDat($i) "70"
			}

		# locate x,y data for temperature
			set y0 [expr $altMax * [expr $i] / 24]
			scan $tDat($i) "%f %*s" x0

		# plot circle for no-wind data
			plotCircle $x0 $y0 2 $color

		# plot wind-data
			if {$wind($i) != ""}  {
				scan $wind($i) "%s %d" dir spd

				if {$dir == "Calm"}  continue

				if {$dir == "Variable"}  {
					plotCircle $x0 $y0 $spd $color
					continue
				}

				set x1 [expr $spd * $dirSin($dir)]
				set y1 [expr $spd * -$dirCos($dir)]
				plotLineDelta $x0 $y0 $x1 $y1 $color
			}
		}

		set latestReading   $wind(0)

	# display current info
		set  fld [split $time(0) " "]

		if { [llength $fld] > 3 } {
			set timeStr "[lindex $fld 1] [lindex $fld 2]"
		} else  {
			set timeStr "[lindex $fld 1]"
		}

		displayRight "$station $timeStr $tDat(0) $wind(0)"
	}

# --------------------------------------------------------------------
	proc procTemp {fid altMax color}  {
		global  nRow time tDat wind

	# process file
		set sct   0
		set nRow  0
		set obsDat($nRow)   ""

		while { [gets $fid line] >= 0}  {
			regsub -all "<\[^>\]*>" $line  "" s
			
			if { $sct > 0 }  {
				if [regexp "<TR>" $line]  {
					set nRow [expr $nRow + 1]
					set obsDat($nRow)   ""
				}
				
				if [regexp "/TABLE" $line]  {
					set sct 0
				}

				if [regexp "Latest" $line]  {
					set nRow  0
					set obsDat($nRow)   ":"
				}

				set obsDat($nRow) [concat $obsDat($nRow) $s  ]
				set obsDat($nRow) [concat $obsDat($nRow) ":" ]

			}

			if [regexp "24 Hour Summary" $s]  {
				set sct 1
			}
		}

	# extract data
		for {set i 0} {$i <= $nRow} {incr i 1}  {
			set  fld [split $obsDat($i) ":"]

			set time($i) [ lindex $fld 3  ]
			set tDat($i) [ lindex $fld 5  ]
			set wind($i) [ lindex $fld 11 ]
		}

	# plot
		plotData $altMax $color
	}


# ====================================================================
# process temperature data

# defines
		set server     "http://weather.noaa.gov"
		set protoPage  "/weather/current/STATION.html"

		set nStations [llength $stations]

# process pages
		for {set i 0} {$i < $nStations} {incr i 1}  {
			set color   [lindex $colorList $i]
			set station [lindex $stations $i]
			regsub "STATION" $protoPage  $station page

			set localFile "tmp/$station.html"

		# if local file > 1 hour old, update from network
			if [file exists $localFile]  {
				set delta [expr $currentTime - [getFileTimestamp $localFile]]

				if {$delta > $_1hour}  {
					readUrl $server $page $localFile
				}
			} else  {
				readUrl $server $page $localFile
			}

		# reopen local file and process it
			set   fid [open $localFile r]

			procTemp $fid $altMax $color
			plotText    "$station $latestReading" $color

			close   $fid
		}
